@@ -1,6 +1,6 @@
-names.summary.zelig <- function(object,...) {
-  res <- names.default(object, ...)[1:4]
-  qi.names <- names.default(object$qi.stats, ...)
+names.summary.zelig <- function(x, ...) {
+  res <- names.default(x, ...)[1:4]
+  qi.names <- names.default(x$qi.stats, ...)
   for (i in 1:length(qi.names)) {
     qi.names[i] <- paste("qi.stats$", qi.names[i], sep = "")
   }
